@@ -369,6 +369,12 @@ public:
      */
     KMimeType::Ptr mimeTypePtr() const;
 
+    /**
+     * @return true if we have determined the final icon of this file already.
+     * @since 4.10.2
+     */
+    bool isFinalIconKnown() const;
+
     /**
      * @return true if we have determined the mimetype of this file already,
      * i.e. if determineMimeType() will be fast. Otherwise it will have to
