@@ -191,8 +191,10 @@ public:
      */
     static bool file_copy( const KUrl& src, const KUrl& target, QWidget* window = 0 );
     /// @deprecated, use file_copy instead
+#ifndef KDE_NO_DEPRECATED
     static KDE_DEPRECATED bool copy( const KUrl& src, const KUrl& target,
                                      QWidget* window = 0 );
+#endif
 
     /**
      * Alternative method for copying over the network.
@@ -226,14 +228,18 @@ public:
      * Moves or renames one file or directory.
      * @deprecated use KIO::move and then KIO::NetAccess::synchronousRun (or job->exec())
      */
+#ifndef KDE_NO_DEPRECATED
     static KDE_DEPRECATED bool move( const KUrl& src, const KUrl& target, QWidget* window = 0L );
+#endif
 
     /**
      * Full-fledged equivalent of KIO::move.
      * Moves or renames a list of files or directories.
      * @deprecated use KIO::move and then KIO::NetAccess::synchronousRun (or job->exec())
      */
+#ifndef KDE_NO_DEPRECATED
     static KDE_DEPRECATED bool move( const KUrl::List& src, const KUrl& target, QWidget* window = 0L );
+#endif
 
     /**
      * Tests whether a URL exists.
@@ -249,8 +255,12 @@ public:
      *               again be prompted for passwords as needed.
      * @return true if the URL exists and we can do the operation specified by
      *              @p source, false otherwise
+     *
+     * @deprecated use the StatSide enum instead of the bool source
      */
+#ifndef KDE_NO_DEPRECATED
     static KDE_DEPRECATED bool exists(const KUrl& url, bool source, QWidget* window);
+#endif
 
     /**
      * Tests whether a URL exists.
