@@ -78,9 +78,9 @@ class PLASMA_EXPORT Applet : public QGraphicsWidget
 {
     Q_OBJECT
     Q_PROPERTY(bool hasConfigurationInterface READ hasConfigurationInterface)
-    Q_PROPERTY(QString name READ name)
-    Q_PROPERTY(QString pluginName READ pluginName)
-    Q_PROPERTY(QString category READ category)
+    Q_PROPERTY(QString name READ name CONSTANT)
+    Q_PROPERTY(QString pluginName READ pluginName CONSTANT)
+    Q_PROPERTY(QString category READ category CONSTANT)
     Q_PROPERTY(ImmutabilityType immutability READ immutability WRITE setImmutability)
     Q_PROPERTY(bool hasFailedToLaunch READ hasFailedToLaunch WRITE setFailedToLaunch)
     Q_PROPERTY(bool isBusy READ isBusy WRITE setBusy) //KDE5: remove
@@ -88,7 +88,7 @@ class PLASMA_EXPORT Applet : public QGraphicsWidget
     Q_PROPERTY(bool configurationRequired READ configurationRequired WRITE setConfigurationRequired)
     Q_PROPERTY(QRectF geometry READ geometry WRITE setGeometry)
     Q_PROPERTY(bool shouldConserveResources READ shouldConserveResources)
-    Q_PROPERTY(uint id READ id)
+    Q_PROPERTY(uint id READ id CONSTANT)
     Q_PROPERTY(bool userConfiguring READ isUserConfiguring)
     Q_PROPERTY(BackgroundHints backgroundHints READ backgroundHints WRITE setBackgroundHints)
     Q_ENUMS(BackgroundHints)
