@@ -32,11 +32,17 @@ class PackagePrivate
 {
 public:
     PackagePrivate(const PackageStructure::Ptr st, const QString &p);
+    PackagePrivate(const PackageStructure::Ptr st, const QString &packageRoot, const QString &path);
+    PackagePrivate(const PackagePrivate &other);
     ~PackagePrivate();
 
+    PackagePrivate &operator=(const PackagePrivate &rhs);
+
+    void setPathFromStructure(const QString &p);
     void publish(AnnouncementMethods methods);
     void unpublish();
     bool isPublished() const;
+    bool isValid();
 
 #ifdef QCA2_FOUND
     void updateHash(const QString &basePath, const QString &subPath, const QDir &dir, QCA::Hash &hash);
